﻿//
// This file, __Frame1.h, is encoded in UTF-8, so that we can support
// unicode messages.
//

#define HANDLER_TIMEOUT 400
//
// The library of MQTT (mqtt.a) for HMIWorks allocates 256 bytes for
// both topics and messages. Here we must declare a buffer of char not
// shorter than 256.
//
#define BUF_LEN 256
//
// The buffers of topics and messages that we subscribe.
//
char topic_recv[BUF_LEN];
char msg_recv[BUF_LEN];


void BitButton7OnClick(tWidget *pWidget)
{
   //
	// Connect to remote MQTT broker. MQTT port = 1883.
	// client_id is used to be identified by the server. We suggest users to
	// make client_id from [0-9A-Za-z] and make client_id of length 1 to 23
	// characters because the MQTT standard (MQTT Version 3.1.1) tells
	// the broker must support these.
	//

   char* client_id = "ICPDAS_MQTT_Demo";

   hmi_MQTTConnect( "10.0.8.28" , 1883, client_id, "", "");
}

void BitButton8OnClick(tWidget *pWidget)
{
   hmi_MQTTDisconnect();
}

void BitButton10OnClick(tWidget *pWidget) // Publish
{
   int qos = CheckBoxValueGet(&CheckBox29);
   bool retain = CheckBoxValueGet(&CheckBox31);
   char * topic = "Hello";
   char * msg1 = "World";
   char * msg2 = "MQTT";
   char * msg3 = "ICPDAS";

   if(CheckBoxValueGet(&CheckBox13) == 1){
      hmi_MQTTPublish(qos, retain, topic, msg1);
   }else if(CheckBoxValueGet(&CheckBox14) == 1){
      hmi_MQTTPublish(qos, retain, topic, msg2);
   }else if(CheckBoxValueGet(&CheckBox23) == 1){
      hmi_MQTTPublish(qos, retain, topic, msg3);
   }
}

// The callback function is launched when a specified topic is received.
// The MQTT_Packet information is recycled after returning from the
// callback function. So, have a copy of the information if you need.
// MQTT_MSG_TOPIC(p)     // get topic name from MQTT_Packet
// MQTT_MSG_TOPIC_LEN(p) // get topic length from MQTT_Packet
// MQTT_MSG_DATA(p)      // get data from MQTT_Packet
// MQTT_MSG_DATA_LEN(p)  // get data length from MQTT_Packet

void MsgHandler(MQTT_Packet *p)
{
   int len = MQTT_MSG_TOPIC_LEN(p);
   ustrncpy(topic_recv, MQTT_MSG_TOPIC(p), len);
   topic_recv[ len ] = 0; // NULL terminal

   len = MQTT_MSG_DATA_LEN(p);
   ustrncpy(msg_recv, MQTT_MSG_DATA(p), len);
   msg_recv[ len ] = 0; // NULL terminal

   LabelTextSet(&Label4, topic_recv);
   LabelTextSet(&Label5, msg_recv);
}

void BitButton16OnClick(tWidget *pWidget) // Subscribe Hello
{
   int qos = CheckBoxValueGet(&CheckBox26);
   hmi_MQTTSubscribe(qos, "Hello", MsgHandler);
   // This function subscribes to a topic from a broker, and assigns a new
   // callback function MsgHandler for the topic.
   // Topics can share a single callback function, or have different ones.

}

void BitButton18OnClick(tWidget *pWidget) // Unsubscribe Hello
{
  hmi_MQTTUnsubscribe("Hello");
}

void Timer6OnExecute(tWidget *pWidget)
{
// The hmi_MQTTProcess function process the MQTT messages, and then returns MQTT
// connection state: -1=invalid, 2=connecting, 3=connected/ready.
   switch(hmi_MQTTProcess())
   {
   case -1:
      LabelTextSet(&Label24,"Disconnected");
      break;
   case 2:
      LabelTextSet(&Label24,"Connecting");
      break;
   case 3:
      LabelTextSet(&Label24,"Connected");
      break;
   default:
      LabelTextSet(&Label24,"Disconnected");
      break;
   }

}


void CheckBox13OnChange(tWidget *pWidget, unsigned long bSelected)
{
   if(CheckBoxValueGet(&CheckBox13) == 1){
      CheckBoxValueSet(&CheckBox14, 0);
      CheckBoxValueSet(&CheckBox23, 0);
   }
}

void CheckBox14OnChange(tWidget *pWidget, unsigned long bSelected)
{
    if(CheckBoxValueGet(&CheckBox14) == 1){
      CheckBoxValueSet(&CheckBox13, 0);
      CheckBoxValueSet(&CheckBox23, 0);
   }
}

void CheckBox23OnChange(tWidget *pWidget, unsigned long bSelected)
{
    if(CheckBoxValueGet(&CheckBox23) == 1){
      CheckBoxValueSet(&CheckBox13, 0);
      CheckBoxValueSet(&CheckBox14, 0);
   }
}

void Frame12OnCreate()
{
   CheckBoxValueSet(&CheckBox13, 1);
}
